AsserestHttpProperty class final

An AsserestProperty to specify the following test in HTTP.

Constructors

AsserestHttpProperty(Uri url, bool accessible, Duration timeout, int? tryCount, HttpRequestMethod method, Map<String, String>? headers, Object? body)

Properties

accessible → bool
Determine it is accessible before timeout.
final
body → Object?
Body content of the following request.
final
hashCode → int
The hash code for this object.
no setterinherited
headers → UnmodifiableMapView<String, String>
Header of the request.
final
method → HttpRequestMethod
Method uses for making request and asserting HTTP response.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeout → Duration
Define Duration that url must be established entire connection in this windows. Otherwise, it counts as inaccessible.
final
tryCount → int?
Count of retrying connection.
final
url → Uri
The testing url.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited