NonNullBodyRequiredException class final

An AsserestException for detect the given HttpRequestMethod is required body content to make request.

Implemented types

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String
finalinherited
method → HttpRequestMethod
An method uses that requiredHttpRequestMethod.bodyRequired
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.

Operators

operator ==(Object other) → bool
The equality operator.
inherited